==> hubzero-cms-1.2.2_1.2.2.2.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.2/cms/modules/mod_xwhosonline/mod_xwhosonline.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

// Include the logic only once
require_once(dirname(__FILE__) . DS . 'helper.php');

if (version_compare(JVERSION, '1.6', 'lt'))
{
	// Editor usertype check
	$jacl = JFactory::getACL();
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'super administrator');
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'administrator');
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'manager');
}

$modxwhosonline = new modXWhosonline($params, $module);
$modxwhosonline->display();

==> hubzero-cms_20121220.1.orig.tar.gz: hubzero-cms-20121220.1/cms/modules/mod_xwhosonline/mod_xwhosonline.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

// Include the logic only once
require_once(dirname(__FILE__) . DS . 'helper.php');

if (version_compare(JVERSION, '1.6', 'lt'))
{
	// Editor usertype check
	$jacl =& JFactory::getACL();
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'super administrator');
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'administrator');
	$jacl->addACL('mod_xwhosonline', 'manage', 'users', 'manager');
}

$modxwhosonline = new modXWhosonline($params, $module);
$modxwhosonline->display();
